@@ -1,6 +1,6 @@
 # kas - setup tool for bitbake based projects
 #
-# Copyright (c) Siemens AG, 2017-2018
+# Copyright (c) Siemens AG, 2017-2020
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -35,7 +35,7 @@ class Config:
     """
         Implements the kas configuration based on config files.
     """
-    def __init__(self, filename, target, task=None):
+    def __init__(self, filename, target=None, task=None):
         self._override_target = target
         self._override_task = task
         self._config = {}
@@ -53,6 +53,12 @@ class Config:
         self.handler = IncludeHandler(self.filenames)
         self.repo_dict = self._get_repo_dict()
 
+    def get_build_system(self):
+        """
+            Returns the pre-selected build system
+        """
+        return self._config.get('build_system', '')
+
     def find_missing_repos(self):
         """
             Returns repos that are in config but not on disk
@@ -164,8 +170,8 @@ class Config:
         """
             Returns the multiconfig array as bitbake string
         """
-        multiconfigs = []
+        multiconfigs = set()
         for target in self.get_bitbake_targets():
             if target.startswith('multiconfig:') or target.startswith('mc:'):
-                multiconfigs.append(target.split(':')[1])
+                multiconfigs.add(target.split(':')[1])
         return ' '.join(multiconfigs)
