@@ -40,19 +40,20 @@ class Repo:
         Represents a repository in the kas configuration.
     """
 
-    def __init__(self, url, path, refspec, layers, patches,
+    def __init__(self, name, url, path, refspec, layers, patches,
                  disable_operations):
+        self.name = name
         self.url = url
         self.path = path
         self.refspec = refspec
         self._layers = layers
         self._patches = patches
-        self.name = os.path.basename(self.path)
         self.operations_disabled = disable_operations
 
     def __getattr__(self, item):
         if item == 'layers':
-            return [os.path.join(self.path, layer) for layer in self._layers]
+            return [os.path.join(self.path, layer).rstrip(os.sep)
+                    for layer in self._layers]
         elif item == 'qualified_name':
             url = urlparse(self.url)
             return ('{url.netloc}{url.path}'
@@ -131,10 +132,10 @@ class Repo:
                     path = os.path.join(get_context().kas_work_dir, path)
 
         if typ == 'git':
-            return GitRepo(url, path, refspec, layers, patches,
+            return GitRepo(name, url, path, refspec, layers, patches,
                            disable_operations)
         if typ == 'hg':
-            return MercurialRepo(url, path, refspec, layers, patches,
+            return MercurialRepo(name, url, path, refspec, layers, patches,
                                  disable_operations)
         raise NotImplementedError('Repo type "%s" not supported.' % typ)
 
@@ -182,16 +183,13 @@ class RepoImpl(Repo):
             return retc
 
         # Make sure the remote origin is set to the value
-        # in the kas file to avoid suprises
+        # in the kas file to avoid surprises
         try:
             (retc, output) = await run_cmd_async(
                 self.set_remote_url_cmd(),
                 cwd=self.path,
-                fail=False,
                 liveupdate=False)
             if retc != 0:
-                logging.info('Changing remote URL to %s failed with error: %s',
-                             self.effective_url, output.strip())
                 return retc
         except NotImplementedError:
             logging.warning('Repo implementation does not support changing '
