@@ -25,14 +25,6 @@ import shutil
 from kas import kas
 from kas.libkas import run_cmd
 
-import pytest
-
-
-@pytest.fixture
-def changedir():
-    yield
-    os.chdir(os.path.join(os.path.dirname(__file__), '..'))
-
 
 def test_refspec_switch(changedir, tmpdir):
     """
@@ -49,7 +41,7 @@ def test_refspec_switch(changedir, tmpdir):
                            fail=False, liveupdate=False)
     assert rc != 0
     assert output.strip() == ''
-    (rc, output) = run_cmd(['git', 'rev-parse', '-q', 'HEAD'], cwd='kas',
+    (rc, output) = run_cmd(['git', 'rev-parse', 'HEAD'], cwd='kas',
                            fail=False, liveupdate=False)
     assert rc == 0
     assert output.strip() == '907816a5c4094b59a36aec12226e71c461c05b77'
@@ -67,7 +59,7 @@ def test_refspec_switch(changedir, tmpdir):
                            fail=False, liveupdate=False)
     assert rc != 0
     assert output.strip() == ''
-    (rc, output) = run_cmd(['git', 'rev-parse', '-q', 'HEAD'], cwd='kas2',
+    (rc, output) = run_cmd(['git', 'rev-parse', 'HEAD'], cwd='kas2',
                            fail=False, liveupdate=False)
     assert rc == 0
     assert output.strip() == '907816a5c4094b59a36aec12226e71c461c05b77'
